Module request

Module request 

Abstract types representing requests and how they are executed.

Structs

Request
A consuming builder which can be used to build up API calls.

Traits

Executable
Describes an API call which can be executed.

Type Aliases

AccountRequest
A type alias with Request<_, Account> specific functions.
ActionRequest
A type alias with Request<_, Action> specific functions.
CertificateRequest
A type alias with Request<_, Certificate> specific functions.
CustomImageRequest
A type alias with Request<_, CustomImage> specific functions.
DomainRecordRequest
A type alias with Request<_, DomainRecord> specific functions.
DomainRequest
A type alias with Request<_, Domain> specific functions.
DropletActionRequest
A type alias with Request<_, DropletAction> specific functions.
DropletRequest
A type alias with Request<_, Droplet> specific functions.
FloatingIpActionRequest
A type alias with Request<_, FloatingIpAction> specific functions.
FloatingIpRequest
A type alias with Request<_, FloatingIp> specific functions.
ImageActionRequest
A type alias with Request<_, ImageAction> specific functions.
ImageRequest
A type alias with Request<_, Image> specific functions.
LoadBalancerRequest
A type alias with Request<_, LoadBalancer> specific functions.
RegionRequest
A type alias with Request<_, Region> specific functions.
SizeRequest
A type alias with Request<_, Size> specific functions.
SnapshotRequest
A type alias with Request<_, Snapshot> specific functions.
SshKeyRequest
A type alias with Request<_, SshKey> specific functions.
TagRequest
A type alias with Request<_, Tag> specific functions.
VolumeActionRequest
A type alias with Request<_, VolumeAction> specific functions.
VolumeRequest
A type alias with Request<_, Volume> specific functions.