DropletRequest

Type Alias DropletRequest 

pub type DropletRequest<M, V> = Request<M, V>;
A type alias with Request<_, Droplet> specific functions.

Aliased Type

pub struct DropletRequest<M, V> { /* private fields */ }

Implementations

Source

impl DropletRequest<Create, Droplet>

pub fn ssh_keys<D>(self, val: Vec<D>) -> Self
where D: Display + Serialize,

An array containing the IDs or fingerprints of the SSH keys that you wish to embed in the Droplet’s root account upon creation.

Digital Ocean Documentation.

pub fn backups(self, val: bool) -> Self

A boolean indicating whether automated backups should be enabled for the Droplet. Automated backups can only be enabled when the Droplet is created.

Digital Ocean Documentation.

pub fn ipv6(self, val: bool) -> Self

A boolean indicating whether IPv6 is enabled on the Droplet.

Digital Ocean Documentation.

pub fn private_networking(self, val: bool) -> Self

A boolean indicating whether private networking is enabled for the Droplet. Private networking is currently only available in certain regions.

Digital Ocean Documentation.

pub fn user_data(self, val: bool) -> Self

A string containing ‘user data’ which may be used to configure the Droplet on first boot, often a ‘cloud-config’ file or Bash script. It must be plain text and may not exceed 64 KiB in size.

Digital Ocean Documentation.

pub fn monitoring(self, val: bool) -> Self

A boolean indicating whether to install the DigitalOcean agent for monitoring.

Digital Ocean Documentation.

pub fn volumes(self, val: Vec<String>) -> Self

A flat array including the unique string identifier for each Block Storage volume to be attached to the Droplet. At the moment a volume can only be attached to a single Droplet.

Digital Ocean Documentation.

pub fn tags(self, val: Vec<String>) -> Self

A flat array of tag names as strings to apply to the Droplet after it is created. Tag names can either be existing or new tags.

Digital Ocean Documentation.

Source

impl DropletRequest<Create, Vec<Droplet>>

pub fn ssh_keys<D>(self, val: Vec<D>) -> Self
where D: Display + Serialize,

An array containing the IDs or fingerprints of the SSH keys that you wish to embed in the Droplet’s root account upon creation.

Digital Ocean Documentation.

pub fn backups(self, val: bool) -> Self

A boolean indicating whether automated backups should be enabled for the Droplet. Automated backups can only be enabled when the Droplet is created.

Digital Ocean Documentation.

pub fn ipv6(self, val: bool) -> Self

A boolean indicating whether IPv6 is enabled on the Droplet.

Digital Ocean Documentation.

pub fn private_networking(self, val: bool) -> Self

A boolean indicating whether private networking is enabled for the Droplet. Private networking is currently only available in certain regions.

Digital Ocean Documentation.

pub fn user_data(self, val: bool) -> Self

A string containing ‘user data’ which may be used to configure the Droplet on first boot, often a ‘cloud-config’ file or Bash script. It must be plain text and may not exceed 64 KiB in size.

Digital Ocean Documentation.

pub fn monitoring(self, val: bool) -> Self

A boolean indicating whether to install the DigitalOcean agent for monitoring.

Digital Ocean Documentation.

pub fn volumes(self, val: Vec<String>) -> Self

A flat array including the unique string identifier for each Block Storage volume to be attached to the Droplet. At the moment a volume can only be attached to a single Droplet.

Digital Ocean Documentation.

pub fn tags(self, val: Vec<String>) -> Self

A flat array of tag names as strings to apply to the Droplet after it is created. Tag names can either be existing or new tags.

Digital Ocean Documentation.

Source

impl DropletRequest<Get, Droplet>

Source

impl DropletRequest<Get, Droplet>

pub fn actions(self) -> DropletActionRequest<List, Vec<Action>>

pub fn enable_backups(self) -> DropletActionRequest<Create, Action>

pub fn disable_backups(self) -> DropletActionRequest<Create, Action>

pub fn reboot(self) -> DropletActionRequest<Create, Action>

pub fn power_cycle(self) -> DropletActionRequest<Create, Action>

pub fn shutdown(self) -> DropletActionRequest<Create, Action>

pub fn power(self, val: bool) -> DropletActionRequest<Create, Action>

pub fn restore<D: Display>( self, image: D, ) -> DropletActionRequest<Create, Action>

pub fn password_reset(self) -> DropletActionRequest<Create, Action>

pub fn resize<S>( self, size: S, disk: bool, ) -> DropletActionRequest<Create, Action>
where S: AsRef<str> + Serialize + Display,

pub fn rebuild<S>(self, image: S) -> DropletActionRequest<Create, Action>
where S: AsRef<str> + Serialize + Display,

pub fn rename<S>(self, name: S) -> DropletActionRequest<Create, Action>
where S: AsRef<str> + Serialize + Display,

pub fn kernel(self, kernel: usize) -> DropletActionRequest<Create, Action>

pub fn enable_ipv6(self) -> DropletActionRequest<Create, Action>

pub fn enable_private_networking(self) -> DropletActionRequest<Create, Action>

pub fn snapshot<S>(self, name: S) -> DropletActionRequest<Create, Action>
where S: AsRef<str> + Serialize + Display,

pub fn action(self, id: usize) -> DropletActionRequest<Get, Action>