VolumeRequest

Type Alias VolumeRequest 

pub type VolumeRequest<M, V> = Request<M, V>;
A type alias with Request<_, Volume> specific functions.

Aliased Type

pub struct VolumeRequest<M, V> { /* private fields */ }

Implementations

Source

impl VolumeRequest<List, Vec<Volume>>

pub fn region<S: AsRef<str> + Serialize + Display>(self, region: S) -> Self

Source

impl VolumeRequest<Get, Volume>

Source

impl VolumeRequest<Create, Volume>

pub fn description<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self

An optional free-form text field to describe a Block Storage volume.

Digital Ocean Documentation.

pub fn region<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self

The region where the Block Storage volume will be created. When setting a region, the value should be the slug identifier for the region. When you query a Block Storage volume, the entire region object will be returned.

Note: Should not be specified with a snapshot_id.

Digital Ocean Documentation.

pub fn snapshot_id<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self

The unique identifier for the volume snapshot from which to create the volume.

Note: Should not be specified with a region_id.

Digital Ocean Documentation.

Source

impl VolumeRequest<Get, Volume>