Abstract types representing requests and how they are executed.
Structs
- Request
- A consuming builder which can be used to build up API calls.
Traits
- Executable
- Describes an API call which can be executed.
Type Aliases
- Account
Request - A type alias with
Request<_, Account>specific functions. - Action
Request - A type alias with
Request<_, Action>specific functions. - Certificate
Request - A type alias with
Request<_, Certificate>specific functions. - Custom
Image Request - A type alias with
Request<_, CustomImage>specific functions. - Domain
Record Request - A type alias with
Request<_, DomainRecord>specific functions. - Domain
Request - A type alias with
Request<_, Domain>specific functions. - Droplet
Action Request - A type alias with
Request<_, DropletAction>specific functions. - Droplet
Request - A type alias with
Request<_, Droplet>specific functions. - Floating
IpAction Request - A type alias with
Request<_, FloatingIpAction>specific functions. - Floating
IpRequest - A type alias with
Request<_, FloatingIp>specific functions. - Image
Action Request - A type alias with
Request<_, ImageAction>specific functions. - Image
Request - A type alias with
Request<_, Image>specific functions. - Load
Balancer Request - A type alias with
Request<_, LoadBalancer>specific functions. - Region
Request - A type alias with
Request<_, Region>specific functions. - Size
Request - A type alias with
Request<_, Size>specific functions. - Snapshot
Request - A type alias with
Request<_, Snapshot>specific functions. - SshKey
Request - A type alias with
Request<_, SshKey>specific functions. - TagRequest
- A type alias with
Request<_, Tag>specific functions. - Volume
Action Request - A type alias with
Request<_, VolumeAction>specific functions. - Volume
Request - A type alias with
Request<_, Volume>specific functions.