pub type DropletRequest<M, V> = Request<M, V>;Expand description
A type alias with Request<_, Droplet> specific functions.
Aliased Type
pub struct DropletRequest<M, V> { /* private fields */ }Implementations
Sourceimpl DropletRequest<Create, Droplet>
impl DropletRequest<Create, Droplet>
Sourcepub fn ssh_keys<D>(self, val: Vec<D>) -> Self
pub fn ssh_keys<D>(self, val: Vec<D>) -> Self
An array containing the IDs or fingerprints of the SSH keys that you wish to embed in the Droplet’s root account upon creation.
Sourcepub fn backups(self, val: bool) -> Self
pub fn backups(self, val: bool) -> Self
A boolean indicating whether automated backups should be enabled for the Droplet. Automated backups can only be enabled when the Droplet is created.
Sourcepub fn ipv6(self, val: bool) -> Self
pub fn ipv6(self, val: bool) -> Self
A boolean indicating whether IPv6 is enabled on the Droplet.
Sourcepub fn private_networking(self, val: bool) -> Self
pub fn private_networking(self, val: bool) -> Self
A boolean indicating whether private networking is enabled for the Droplet. Private networking is currently only available in certain regions.
Sourcepub fn user_data(self, val: bool) -> Self
pub fn user_data(self, val: bool) -> Self
A string containing ‘user data’ which may be used to configure the Droplet on first boot, often a ‘cloud-config’ file or Bash script. It must be plain text and may not exceed 64 KiB in size.
Sourcepub fn monitoring(self, val: bool) -> Self
pub fn monitoring(self, val: bool) -> Self
A boolean indicating whether to install the DigitalOcean agent for monitoring.
Sourcepub fn volumes(self, val: Vec<String>) -> Self
pub fn volumes(self, val: Vec<String>) -> Self
A flat array including the unique string identifier for each Block Storage volume to be attached to the Droplet. At the moment a volume can only be attached to a single Droplet.
A flat array of tag names as strings to apply to the Droplet after it is created. Tag names can either be existing or new tags.
Sourceimpl DropletRequest<Create, Vec<Droplet>>
impl DropletRequest<Create, Vec<Droplet>>
Sourcepub fn ssh_keys<D>(self, val: Vec<D>) -> Self
pub fn ssh_keys<D>(self, val: Vec<D>) -> Self
An array containing the IDs or fingerprints of the SSH keys that you wish to embed in the Droplet’s root account upon creation.
Sourcepub fn backups(self, val: bool) -> Self
pub fn backups(self, val: bool) -> Self
A boolean indicating whether automated backups should be enabled for the Droplet. Automated backups can only be enabled when the Droplet is created.
Sourcepub fn ipv6(self, val: bool) -> Self
pub fn ipv6(self, val: bool) -> Self
A boolean indicating whether IPv6 is enabled on the Droplet.
Sourcepub fn private_networking(self, val: bool) -> Self
pub fn private_networking(self, val: bool) -> Self
A boolean indicating whether private networking is enabled for the Droplet. Private networking is currently only available in certain regions.
Sourcepub fn user_data(self, val: bool) -> Self
pub fn user_data(self, val: bool) -> Self
A string containing ‘user data’ which may be used to configure the Droplet on first boot, often a ‘cloud-config’ file or Bash script. It must be plain text and may not exceed 64 KiB in size.
Sourcepub fn monitoring(self, val: bool) -> Self
pub fn monitoring(self, val: bool) -> Self
A boolean indicating whether to install the DigitalOcean agent for monitoring.
Sourcepub fn volumes(self, val: Vec<String>) -> Self
pub fn volumes(self, val: Vec<String>) -> Self
A flat array including the unique string identifier for each Block Storage volume to be attached to the Droplet. At the moment a volume can only be attached to a single Droplet.
A flat array of tag names as strings to apply to the Droplet after it is created. Tag names can either be existing or new tags.