pub type VolumeRequest<M, V> = Request<M, V>;Expand description
A type alias with Request<_, Volume> specific functions.
Aliased Type
pub struct VolumeRequest<M, V> { /* private fields */ }Implementations
Sourceimpl VolumeRequest<Get, Volume>
impl VolumeRequest<Get, Volume>
Sourceimpl VolumeRequest<Create, Volume>
impl VolumeRequest<Create, Volume>
Sourcepub fn description<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self
pub fn description<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self
An optional free-form text field to describe a Block Storage volume.
Sourcepub fn region<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self
pub fn region<S: AsRef<str> + Serialize + Display>(self, val: S) -> Self
The region where the Block Storage volume will be created. When setting a region, the value should be the slug identifier for the region. When you query a Block Storage volume, the entire region object will be returned.
Note: Should not be specified with a snapshot_id.